{% extends 'flask_user/public_base.html' %}

{% block content %}

<h3 class="page-header dainterviewpage">{{ title }}</h3>
<p class="dainterviewpage">{{ word('This is my custom interview page.') }}</p>

<table class="table table-striped dainterviewpage">
  <thead>
    <tr>
      <th>Title</th>
      <th>Started</th>
      <th>Delete</th>
    </tr>
  </thead>
  <tbody>
  {% for interview in interviews %}
    <tr>
      <td>{% if interview['valid'] %}<a href="{{ url_for('index', i=interview['interview_info'].filename, session=interview['interview_info'].key, from_list=1) }}">{{ interview['title'] }}</a>{% else %}{{ interview['title'] }}{% endif %}</td>
      <td>{{ interview['starttime'] }}</td>
      <td><a class="btn btn-warning" href="{{ url_for('interview_list', action='delete', filename=interview['interview_info'].filename, session=interview['interview_info'].key) }}">{{ word('Delete') }}</a></td>
    </tr>
  {% endfor %}
  {% if numinterviews > 0 %}  
    <tr>
      <td>&nbsp;</td>
      <td>&nbsp;</td>
      <td><a id="deleteall" class="btn btn-danger" href="{{ url_for('interview_list', action='deleteall') }}">{{ word('Delete All') }}</a></td>
    </tr>
  {% endif %}
  </tbody>
</table>
{% endblock %}
